@@ -56,6 +56,7 @@
 #include <stdexcept>
 #include <vector>
 #include <iostream>
+#include <set>
 
 void ginac_pyinit_Integer(PyObject*);
 void ginac_pyinit_Float(PyObject*);
@@ -277,6 +278,8 @@ public:
 	const numeric iquo(const numeric &b, numeric &r) const;
 	const numeric gcd(const numeric &b) const;
 	const numeric lcm(const numeric &b) const;
+        void factor(std::vector<std::pair<long, int>>& factors) const;
+        void divisors(std::set<int>& divs) const;
 	
 	int int_length() const;
 
@@ -327,8 +330,8 @@ const numeric tanh(const numeric &x);
 const numeric asinh(const numeric &x);
 const numeric acosh(const numeric &x);
 const numeric atanh(const numeric &x);
-const numeric Li2(const numeric &x);
-const numeric Li2(const numeric &x, const numeric &n, PyObject* parent);
+const numeric Li2(const numeric &x, PyObject* parent=nullptr);
+const numeric Li2(const numeric &x, const numeric &n, PyObject* parent=nullptr);
 const numeric stieltjes(const numeric &x);
 const numeric zeta(const numeric &x);
 const numeric lgamma(const numeric &x);
@@ -338,6 +341,7 @@ const numeric psi(const numeric &x);
 const numeric psi(const numeric &n, const numeric &x);
 const numeric factorial(const numeric &n);
 const numeric doublefactorial(const numeric &n);
+const numeric binomial(unsigned long n, unsigned long k);
 const numeric binomial(const numeric &n, const numeric &k);
 const numeric bernoulli(const numeric &n);
 const numeric hypergeometric_pFq(const std::vector<numeric>& a, const std::vector<numeric>& b, const numeric &z, PyObject* parent);
